@@ -12,19 +12,11 @@ module ActionDispatch
         @name = @options.delete(:name) || driver_type
         @capabilities = capabilities
 
-        if [:poltergeist, :webkit].include?(driver_type)
-          ActiveSupport::Deprecation.warn <<~MSG.squish
-            Poltergeist and capybara-webkit are not maintained already.
-            Driver registration of :poltergeist or :webkit is deprecated and will be removed in Rails 7.1.
-            You can still use :selenium, and also :cuprite is available for alternative to Poltergeist.
-          MSG
-        end
-
         if driver_type == :selenium
           gem "selenium-webdriver", ">= 4.0.0"
           require "selenium/webdriver"
           @browser = Browser.new(options[:using])
-          @browser.preload
+          @browser.preload unless @options[:browser] == :remote
         else
           @browser = nil
         end
@@ -38,7 +30,7 @@ module ActionDispatch
 
       private
         def registerable?
-          [:selenium, :poltergeist, :webkit, :cuprite, :rack_test].include?(@driver_type)
+          [:selenium, :cuprite, :rack_test, :playwright].include?(@driver_type)
         end
 
         def register
@@ -47,10 +39,9 @@ module ActionDispatch
           Capybara.register_driver name do |app|
             case @driver_type
             when :selenium then register_selenium(app)
-            when :poltergeist then register_poltergeist(app)
-            when :webkit then register_webkit(app)
             when :cuprite then register_cuprite(app)
             when :rack_test then register_rack_test(app)
+            when :playwright then register_playwright(app)
             end
           end
         end
@@ -65,16 +56,6 @@ module ActionDispatch
           end
         end
 
-        def register_poltergeist(app)
-          Capybara::Poltergeist::Driver.new(app, @options.merge(window_size: @screen_size))
-        end
-
-        def register_webkit(app)
-          Capybara::Webkit::Driver.new(app, Capybara::Webkit::Configuration.to_hash.merge(@options)).tap do |driver|
-            driver.resize_window_to(driver.current_window_handle, *@screen_size)
-          end
-        end
-
         def register_cuprite(app)
           Capybara::Cuprite::Driver.new(app, @options.merge(window_size: @screen_size))
         end
@@ -83,6 +64,17 @@ module ActionDispatch
           Capybara::RackTest::Driver.new(app, respect_data_method: true, **@options)
         end
 
+        def register_playwright(app)
+          screen = { width: @screen_size[0], height: @screen_size[1] } if @screen_size
+          options = {
+            screen: screen,
+            viewport: screen,
+            **@options
+          }.compact
+
+          Capybara::Playwright::Driver.new(app, **options)
+        end
+
         def setup
           Capybara.current_driver = name
         end
